@@ -1,7 +1,6 @@
 #' Get path to feather example files
 #'
-#' @description
-#' \code{feather_example} gets the path of a specific example
+#' @description `feather_example` gets the path of a specific example
 #'
 #' @param x example file
 #' @export
@@ -10,8 +9,7 @@ feather_example <- function(x) {
   system.file("feather", x, mustWork = TRUE, package = "feather")
 }
 
-#' @description
-#' \code{feather_examples} gets the path of all examples
+#' @description `feather_examples` gets the path of all examples
 #'
 #' @export
 #' @rdname feather_example
@@ -19,14 +17,3 @@ feather_examples <- function() {
   path <- feather_example("")
   stats::setNames(dir(path, full.names = TRUE), dir(path))
 }
-
-
-
-dim_desc <- function(x) {
-  paste0("[", paste0(big_mark(x), collapse = " x "), "]")
-}
-
-big_mark <- function(x, ...) {
-  mark <- if (identical(getOption("OutDec"), ",")) "." else ","
-  formatC(x, big.mark = mark, ...)
-}
